@@ -4,6 +4,7 @@ import yaml
 import socket
 import logging
 import asyncio
+import platform
 import threading
 import tornado.web
 import tornado.ioloop
@@ -867,12 +868,24 @@ def start():
             (r'/(.*)', tornado.web.StaticFileHandler, {'path': 'webapp/www', 'default_filename': 'index.html'}),
         ]
 
+    debug = 'dev' == app_profile  # 开发模式缺省启动debug
+    try:
+        process_number = yml['process_number']  # 如果yml配置文件中指定了进程数，则强制使用
+        if debug:
+            debug = 1 == process_number  # 开发模式模式下，如果yml配置文件中指定了进程数不为1，则强制关闭debug
+    except:
+        process_number = 1  # 如果yml配置文件中未指定进程数，则设定进程数=1
+
+    if platform.system() != 'Linux':  # 非Linux环境中一律设定进程数=1
+        process_number = 1
+
     app = tornado.web.Application(
         handlers=handlers,
-        debug=('dev' == app_profile)
+        debug=debug
     )
     http_server = tornado.httpserver.HTTPServer(app, max_buffer_size=1000 * 1024 * 1024)
-    http_server.listen(port)
+    http_server.bind(port)
+    http_server.start(num_processes=process_number)
 
     logging.critical('##################################################')
     logging.critical('    微服务： {}/{} started ...'.format(cname, ename))
